Crate lockset_vault_provider

Crate lockset_vault_provider 

Structs

ProviderSecret
Represents a secret retrieved from a provider.

Enums

ProviderError

Traits

VaultProvider
Defines the contract for a connection to an external vault.
VaultProviderFactory
Defines the contract for a factory that creates VaultProvider instances.